import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import static org.junit.jupiter.api.Assertions.*;


class LibraryManagementSystemTestComplete {

    private static Library library;
    private static Book book1;
    private static Book book2;
    private static Member member1;
    private static Member member2;

    @BeforeEach
    void setUp() {
        // Create library and add books and members
        library = new Library();
        book1 = new Book("The Great Gatsby", "F. Scott Fitzgerald");
        book2 = new Book("To Kill a Mockingbird", "Harper Lee");
        member1 = new Member("John Doe", "12345");
        member2 = new Member("Jane Smith", "67890");

        library.addBook(book1);
        library.addBook(book2);
        library.addMember(member1);
        library.addMember(member2);
    }

    @Test
    void testLoanBook() throws Exception {
        library.loanBook(book1, member1);
        assertTrue(book1.isLoaned());
        assertEquals(1, library.getLoans().size());
    }

    @Test
    void testLoanBookNotRegistered() {
        Member newMember = new Member("New Member", "99999");
        assertThrows(Exception.class, () -> library.loanBook(book2, newMember));
    }

    @Test
    void testReturnBook() throws Exception {
        library.loanBook(book1, member1);
        library.returnBook(book1);
        assertFalse(book1.isLoaned());
        assertEquals(0, library.getLoans().size());
    }

    @Test
    void testReturnBookNotLoaned() {
        assertThrows(Exception.class, () -> library.returnBook(book2));
    }

    @Test
    void testAddBook() {
        Book newBook = new Book("1984", "George Orwell");
        library.addBook(newBook);
        assertTrue(library.getBooks().contains(newBook));
    }

    @Test
    void testAddMember() {
        Member newMember = new Member("New Member", "99999");
        library.addMember(newMember);
        assertTrue(library.getMembers().contains(newMember));
    }
}
