# Before:

### CLient.java
```
package Refactoring.LongExample1.Before;

public class Client {
}
```

### CorporateClient.java
```
package Refactoring.LongExample1.Before;

public class CorporateClient extends Client {

    private final double retainer = 500;

    public double amountOwing(int daysWorked) {
        double base = retainer + (daysWorked / 30.0) * monthlyRate();
        double discount = 500.0 + base * 0.02;
        return base - discount;
    }

    private double monthlyRate() {
        return 500;
    }

}
```

### RetailClient.java
```
package Refactoring.LongExample1.Before;

public class RetailClient extends Client {

    public double amountOwing(int daysWorked) {
        double base = daysWorked * dailyRate();
        double discount = base * discountRate();
        return base - discount;
    }

    private double discountRate() {
        return 500;
    }

    private int dailyRate() {
        return 500;
    }
}
```

---
# After 

### Client.java

```
package Refactoring.LongExample1.After2;

public abstract class Client {
    public double amountOwing(int daysWorked) {
        double base = baseAmount(daysWorked);
        return base - discountAmount(base);
    }

    public abstract double baseAmount(int daysWorked);

    public abstract double discountAmount(double base);
}
```

### CorporateClient.java

```
package Refactoring.LongExample1.After2;

public class CorporateClient extends Client {

    private final double retainer = 500;

    public double baseAmount(int daysWorked) {
        return retainer + (daysWorked / 30.0) * monthlyRate();
    }

    public double discountAmount(double base) {
        return 500.0 + base * 0.02;
    }

    private double monthlyRate() {
        return 500;
    }
}
```

### RetailClient.java

```
package Refactoring.LongExample1.After2;

public class RetailClient extends Client {

    public double baseAmount(int daysWorked) {
        return daysWorked * dailyRate();
    }

    public double discountAmount(double base) {
        return base * discountRate();
    }

    private double discountRate() {
        return 500;
    }

    private int dailyRate() {
        return 500;
    }
}
```